@@ -2,9 +2,11 @@ pub mod topic;
 pub mod spu;
 pub mod spg;
 pub mod connector;
+pub mod smartmodule;
 pub mod partition;
 pub mod versions;
 pub mod objects;
+pub mod table;
 mod apis;
 mod request;
 mod response;
