@@ -40,12 +40,16 @@ mod create {
     use fluvio_controlplane_metadata::spu::CustomSpuSpec;
     use fluvio_controlplane_metadata::spg::SpuGroupSpec;
     use fluvio_controlplane_metadata::connector::ManagedConnectorSpec;
+    use fluvio_controlplane_metadata::smartmodule::SmartModuleSpec;
+    use fluvio_controlplane_metadata::table::TableSpec;
     use super::*;
 
     const TOPIC: u8 = 0;
     const CUSTOM_SPU: u8 = 1;
     const SPG: u8 = 2;
     const MANAGED_CONNECTOR: u8 = 3;
+    const SMART_MODULE: u8 = 4;
+    const TABLE: u8 = 5;
 
     #[derive(Debug)]
     /// enum of spec that can be created
@@ -54,6 +58,8 @@ mod create {
         CustomSpu(CustomSpuSpec),
         SpuGroup(SpuGroupSpec),
         ManagedConnector(ManagedConnectorSpec),
+        SmartModule(SmartModuleSpec),
+        Table(TableSpec),
     }
 
     impl Default for AllCreatableSpec {
@@ -72,6 +78,8 @@ mod create {
                     Self::CustomSpu(s) => s.write_size(version),
                     Self::SpuGroup(s) => s.write_size(version),
                     Self::ManagedConnector(s) => s.write_size(version),
+                    Self::SmartModule(s) => s.write_size(version),
+                    Self::Table(s) => s.write_size(version),
                 }
         }
 
@@ -104,6 +112,18 @@ mod create {
                     typ.encode(dest, version)?;
                     s.encode(dest, version)?;
                 }
+
+                Self::SmartModule(s) => {
+                    let typ: u8 = SMART_MODULE;
+                    typ.encode(dest, version)?;
+                    s.encode(dest, version)?;
+                }
+
+                Self::Table(s) => {
+                    let typ: u8 = TABLE;
+                    typ.encode(dest, version)?;
+                    s.encode(dest, version)?;
+                }
             }
 
             Ok(())
@@ -146,6 +166,19 @@ mod create {
                     *self = Self::ManagedConnector(response);
                     Ok(())
                 }
+                TABLE => {
+                    let mut response = TableSpec::default();
+                    response.decode(src, version)?;
+                    *self = Self::Table(response);
+                    Ok(())
+                }
+
+                SMART_MODULE => {
+                    let mut response = SmartModuleSpec::default();
+                    response.decode(src, version)?;
+                    *self = Self::SmartModule(response);
+                    Ok(())
+                }
 
                 // Unexpected type
                 _ => Err(Error::new(
