@@ -17,6 +17,9 @@ use fluvio_controlplane_metadata::spg::SpuGroupSpec;
 use fluvio_controlplane_metadata::store::*;
 use fluvio_controlplane_metadata::partition::PartitionSpec;
 use fluvio_controlplane_metadata::connector::ManagedConnectorSpec;
+use fluvio_controlplane_metadata::smartmodule::SmartModuleSpec;
+use fluvio_controlplane_metadata::table::TableSpec;
+
 use crate::AdminPublicApiKey;
 use crate::AdminRequest;
 
@@ -45,6 +48,8 @@ pub enum ListRequest {
     CustomSpu(Vec<NameFilter>),
     Partition(Vec<NameFilter>),
     ManagedConnector(Vec<NameFilter>),
+    SmartModule(Vec<NameFilter>),
+    Table(Vec<NameFilter>),
 }
 
 impl Default for ListRequest {
@@ -69,6 +74,8 @@ pub enum ListResponse {
     SpuGroup(Vec<Metadata<SpuGroupSpec>>),
     Partition(Vec<Metadata<PartitionSpec>>),
     ManagedConnector(Vec<Metadata<ManagedConnectorSpec>>),
+    SmartModule(Vec<Metadata<SmartModuleSpec>>),
+    Table(Vec<Metadata<TableSpec>>),
 }
 
 impl Default for ListResponse {
@@ -159,6 +166,8 @@ mod encoding {
                 Self::CustomSpu(_) => CustomSpuSpec::LABEL,
                 Self::Partition(_) => PartitionSpec::LABEL,
                 Self::ManagedConnector(_) => ManagedConnectorSpec::LABEL,
+                Self::SmartModule(_) => SmartModuleSpec::LABEL,
+                Self::Table(_) => TableSpec::LABEL,
             }
         }
     }
@@ -175,6 +184,8 @@ mod encoding {
                     Self::Spu(s) => s.write_size(version),
                     Self::Partition(s) => s.write_size(version),
                     Self::ManagedConnector(s) => s.write_size(version),
+                    Self::SmartModule(s) => s.write_size(version),
+                    Self::Table(s) => s.write_size(version),
                 }
         }
 
@@ -192,6 +203,8 @@ mod encoding {
                 Self::Spu(s) => s.encode(dest, version)?,
                 Self::Partition(s) => s.encode(dest, version)?,
                 Self::ManagedConnector(s) => s.encode(dest, version)?,
+                Self::SmartModule(s) => s.encode(dest, version)?,
+                Self::Table(s) => s.encode(dest, version)?,
             }
 
             Ok(())
@@ -242,6 +255,7 @@ mod encoding {
                     *self = Self::Partition(response);
                     Ok(())
                 }
+
                 ManagedConnectorSpec::LABEL => {
                     let mut response: Vec<NameFilter> = vec![];
                     response.decode(src, version)?;
@@ -249,6 +263,20 @@ mod encoding {
                     Ok(())
                 }
 
+                SmartModuleSpec::LABEL => {
+                    let mut response: Vec<NameFilter> = vec![];
+                    response.decode(src, version)?;
+                    *self = Self::SmartModule(response);
+                    Ok(())
+                }
+
+                TableSpec::LABEL => {
+                    let mut response: Vec<NameFilter> = vec![];
+                    response.decode(src, version)?;
+                    *self = Self::Table(response);
+                    Ok(())
+                }
+
                 // Unexpected type
                 _ => Err(Error::new(
                     ErrorKind::InvalidData,
@@ -268,6 +296,8 @@ mod encoding {
                 Self::CustomSpu(_) => CustomSpuSpec::LABEL,
                 Self::Partition(_) => PartitionSpec::LABEL,
                 Self::ManagedConnector(_) => ManagedConnectorSpec::LABEL,
+                Self::SmartModule(_) => SmartModuleSpec::LABEL,
+                Self::Table(_) => TableSpec::LABEL,
             }
         }
     }
@@ -284,6 +314,8 @@ mod encoding {
                     Self::Spu(s) => s.write_size(version),
                     Self::Partition(s) => s.write_size(version),
                     Self::ManagedConnector(s) => s.write_size(version),
+                    Self::SmartModule(s) => s.write_size(version),
+                    Self::Table(s) => s.write_size(version),
                 }
         }
 
@@ -301,6 +333,8 @@ mod encoding {
                 Self::Spu(s) => s.encode(dest, version)?,
                 Self::Partition(s) => s.encode(dest, version)?,
                 Self::ManagedConnector(s) => s.encode(dest, version)?,
+                Self::SmartModule(s) => s.encode(dest, version)?,
+                Self::Table(s) => s.encode(dest, version)?,
             }
 
             Ok(())
@@ -357,6 +391,18 @@ mod encoding {
                     *self = Self::ManagedConnector(response);
                     Ok(())
                 }
+                TableSpec::LABEL => {
+                    let mut response: Vec<Metadata<TableSpec>> = vec![];
+                    response.decode(src, version)?;
+                    *self = Self::Table(response);
+                    Ok(())
+                }
+                SmartModuleSpec::LABEL => {
+                    let mut response: Vec<Metadata<SmartModuleSpec>> = vec![];
+                    response.decode(src, version)?;
+                    *self = Self::SmartModule(response);
+                    Ok(())
+                }
 
                 // Unexpected type
                 _ => Err(Error::new(
