@@ -13,6 +13,8 @@ use fluvio_controlplane_metadata::partition::PartitionSpec;
 use fluvio_controlplane_metadata::store::Epoch;
 use fluvio_controlplane_metadata::message::Message;
 use fluvio_controlplane_metadata::connector::ManagedConnectorSpec;
+use fluvio_controlplane_metadata::smartmodule::SmartModuleSpec;
+use fluvio_controlplane_metadata::table::TableSpec;
 
 use crate::AdminPublicApiKey;
 use crate::AdminRequest;
@@ -35,6 +37,8 @@ pub enum WatchRequest {
     SpuGroup(Epoch),
     Partition(Epoch),
     ManagedConnector(Epoch),
+    SmartModule(Epoch),
+    Table(Epoch),
 }
 
 impl Default for WatchRequest {
@@ -58,6 +62,8 @@ pub enum WatchResponse {
     SpuGroup(MetadataUpdate<SpuGroupSpec>),
     Partition(MetadataUpdate<PartitionSpec>),
     ManagedConnector(MetadataUpdate<ManagedConnectorSpec>),
+    SmartModule(MetadataUpdate<SmartModuleSpec>),
+    Table(MetadataUpdate<TableSpec>),
 }
 
 impl Default for WatchResponse {
@@ -124,6 +130,8 @@ mod encoding {
                 Self::SpuGroup(_) => SpuGroupSpec::LABEL,
                 Self::Partition(_) => PartitionSpec::LABEL,
                 Self::ManagedConnector(_) => ManagedConnectorSpec::LABEL,
+                Self::SmartModule(_) => SmartModuleSpec::LABEL,
+                Self::Table(_) => TableSpec::LABEL,
             }
         }
     }
@@ -139,6 +147,8 @@ mod encoding {
                     Self::Spu(s) => s.write_size(version),
                     Self::Partition(s) => s.write_size(version),
                     Self::ManagedConnector(s) => s.write_size(version),
+                    Self::SmartModule(s) => s.write_size(version),
+                    Self::Table(s) => s.write_size(version),
                 }
         }
 
@@ -155,6 +165,8 @@ mod encoding {
                 Self::Spu(s) => s.encode(dest, version)?,
                 Self::Partition(s) => s.encode(dest, version)?,
                 Self::ManagedConnector(s) => s.encode(dest, version)?,
+                Self::SmartModule(s) => s.encode(dest, version)?,
+                Self::Table(s) => s.encode(dest, version)?,
             }
 
             Ok(())
@@ -199,6 +211,13 @@ mod encoding {
                     Ok(())
                 }
 
+                TableSpec::LABEL => {
+                    let mut response: Epoch = Epoch::default();
+                    response.decode(src, version)?;
+                    *self = Self::Table(response);
+                    Ok(())
+                }
+
                 // Unexpected type
                 _ => Err(Error::new(
                     ErrorKind::InvalidData,
@@ -217,6 +236,8 @@ mod encoding {
                 Self::SpuGroup(_) => SpuGroupSpec::LABEL,
                 Self::Partition(_) => PartitionSpec::LABEL,
                 Self::ManagedConnector(_) => ManagedConnectorSpec::LABEL,
+                Self::SmartModule(_) => SmartModuleSpec::LABEL,
+                Self::Table(_) => TableSpec::LABEL,
             }
         }
     }
@@ -232,6 +253,8 @@ mod encoding {
                     Self::Spu(s) => s.write_size(version),
                     Self::Partition(s) => s.write_size(version),
                     Self::ManagedConnector(s) => s.write_size(version),
+                    Self::SmartModule(s) => s.write_size(version),
+                    Self::Table(s) => s.write_size(version),
                 }
         }
 
@@ -248,6 +271,8 @@ mod encoding {
                 Self::Spu(s) => s.encode(dest, version)?,
                 Self::Partition(s) => s.encode(dest, version)?,
                 Self::ManagedConnector(s) => s.encode(dest, version)?,
+                Self::SmartModule(s) => s.encode(dest, version)?,
+                Self::Table(s) => s.encode(dest, version)?,
             }
 
             Ok(())
@@ -292,6 +317,20 @@ mod encoding {
                     Ok(())
                 }
 
+                SmartModuleSpec::LABEL => {
+                    let mut response = MetadataUpdate::default();
+                    response.decode(src, version)?;
+                    *self = Self::SmartModule(response);
+                    Ok(())
+                }
+
+                TableSpec::LABEL => {
+                    let mut response = MetadataUpdate::default();
+                    response.decode(src, version)?;
+                    *self = Self::Table(response);
+                    Ok(())
+                }
+
                 // Unexpected type
                 _ => Err(Error::new(
                     ErrorKind::InvalidData,
